<!--
  ~ Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
  ~
  ~ Licensed under the Apache License, Version 2.0 (the "License");
  ~ you may not use this file except in compliance with the License.
  ~ You may obtain a copy of the License at
  ~
  ~ http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~ Unless required by applicable law or agreed to in writing, software
  ~ distributed under the License is distributed on an "AS IS" BASIS,
  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  ~ See the License for the specific language governing permissions and
  ~ limitations under the License.
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:template match="ns1:listServicesAndPortsResponse" xmlns:ns1="http://org.apache.axis2/xsd">
        <!--  Link header to be populated by java script -->
        <div id="stubGenMetaInfo"></div>
        <div id="formset">
            <form>
                <fieldset>
                    <legend>Stub Generation options</legend>

                    <xsl:variable name="serviceName"><xsl:value-of select="return/serviceEndpointsData/serviceName"/></xsl:variable>
                    <xsl:variable name="wv" select="return/wsdlVersion"/>


                    <xsl:apply-templates select="return">
                        <xsl:with-param name="wv" select="$wv"/>
                    </xsl:apply-templates>


                    <div>
                        <label>Package Name <font color='red'>*</font></label>
                        <input>
                            <xsl:attribute name="type">text</xsl:attribute>
                            <xsl:attribute name="id">pakageName</xsl:attribute>
                            <xsl:attribute name="size">40</xsl:attribute>
                            <xsl:attribute name="value">org.wso2.wsas.client</xsl:attribute>
                            <xsl:attribute name="tabindex">3</xsl:attribute>
                         </input>
                    </div>
                    <div>
                        <label>Invocation Style</label>
                        <select>
                            <xsl:attribute name="id">invocationStyle</xsl:attribute>
                            <xsl:attribute name="tabindex">4</xsl:attribute>
                            <option value='both'>Both</option>
                            <option value='a'>Asynchronous</option>
                            <option value='s'>Synchronous</option>
                        </select>
                    </div>
                    <div>
                        <label>Databinding</label>
                        <select id='databindingMethod' tabindex="5">
                            <xsl:attribute name="onchange">javascript:codegenUnwrappingSelectorHelper(this);return false;</xsl:attribute>
                            <option value='adb'>ADB</option>
                            <option value='xmlbeans'>XMLBeans</option>
                            <option value='none'>NONE</option>
                        </select>
                    </div>
                    <div>
                        <label>Unpack Classes</label>
                        <select id='unpackClasses' tabindex="6">
                            <option value='true'>True</option>
                            <option value='false'>False</option>
                        </select>
                    </div>
                    <div>
                        <label>Unwrap</label>
                        <select id='unwrap' tabindex="7">
                            <option value='false'>False</option>
                            <option value='true'>True</option>
                        </select>
                    </div>
                    <div>
                        <label>Generate Testcase</label>
                        <select id='generateTestCases' tabindex="8">
                            <option value='false'>False</option>
                            <option value='true'>True</option>
                        </select>
                    </div>


                    <div class='buttonrow'>
                        <input type='button' value='Generate' tabindex="9">
                            <xsl:attribute name="onClick">javascript:stubGenerationSOAPRequest(document.getElementById('pakageName'),document.getElementById('invocationStyle'),document.getElementById('generateTestCases'),document.getElementById('databindingMethod'),document.getElementById('unpackClasses'),'<xsl:value-of select="$serviceName"/>',document.getElementById('portSelectBox'),document.getElementById('unwrap'),document.getElementById('wsdlVersion'));return false;</xsl:attribute>
                            <xsl:attribute name="id">dynamicClientButtonId</xsl:attribute>
                        </input>
                    </div>

                </fieldset>
            </form>
        </div>
    </xsl:template>

    <xsl:template match="return">
        <xsl:param name="wv"/>
        <xsl:if test="$wv='1.1'">
            <div>
                <label>Information from WSDL-1.1</label>
            </div>
        </xsl:if>

        <xsl:if test="$wv='2.0'">
            <div>
                <label>Information from WSDL-2.0</label>
            </div>
        </xsl:if>

        <xsl:apply-templates select="serviceEndpointsData">
            <xsl:with-param name="wv" select="$wv"/>
        </xsl:apply-templates>


    </xsl:template>

    <xsl:template match="serviceEndpointsData">
        <xsl:param name="wv"/>

        <div>
            <label>Service Binding</label><xsl:value-of select="serviceName"/>
        </div>

        <div>
            <label>WSDL Version</label>
            <select id='wsdlVersion' tabindex="1">
                <xsl:attribute name="onchange">javascript:stubGenerationMetaInfo(this[this.selectedIndex].value);return false;</xsl:attribute>
                <xsl:choose>
                    <xsl:when test="$wv='1.1'">
                        <option value='1.1'>1.1</option>
                        <option value='2.0'>2.0</option>
                    </xsl:when>
                    <xsl:otherwise>
                        <option value='2.0'>2.0</option>
                        <option value='1.1'>1.1</option>
                    </xsl:otherwise>
                </xsl:choose>

            </select>
        </div>

        <xsl:if test="$wv='1.1'">
            <div>
                <label>Port</label>
                <select id="portSelectBox" tabindex="2">
                    <xsl:for-each select="endpointNames">
                        <option>
                            <xsl:attribute name="value">
                                <xsl:value-of select="."/>
                            </xsl:attribute>
                            <xsl:value-of select="."/>
                        </option>
                    </xsl:for-each>
                </select>
            </div>
        </xsl:if>

        <xsl:if test="$wv='2.0'">
           <div>
                <label>Endpoints</label>
                <select id="portSelectBox" tabindex="2">
                    <xsl:for-each select="endpointNames">
                        <option>
                            <xsl:attribute name="value">
                                <xsl:value-of select="."/>
                            </xsl:attribute>
                            <xsl:value-of select="."/>
                        </option>
                    </xsl:for-each>
                </select>
            </div>
        </xsl:if>
    </xsl:template>


</xsl:stylesheet>
